@@ -1,65 +1,61 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+#!/usr/bin/python3
 
 """
 rename-flac takes the information from FLAC metadata to batch rename
 the files according to a file-naming scheme.
 
-Usage:
-    rename-flac [--verbose] <scheme> <directory>
-    rename-flac (-h | --help)
-    rename-flac --version
-
-Arguments:
-    <scheme>         The filenaming scheme. Has to be between quotation marks
-    <directory>      The path to the directory containing the album
-
-Options:
-    -h  --help       Shows the help screen
-    --version        Outputs version information
-    --verbose        Runs the program as verbose mode
-
-    These are the options you can use to define the filenaming scheme:
-      %a = Artist  |  %b = Album        |  %c = Composer  |  %d = Date
-      %g = Genre   |  %n = Tracknumber  |  %t = Title
+These are the options you can use to define the filenaming scheme:
+  %a = Artist  |  %b = Album        |  %c = Composer  |  %d = Date
+  %g = Genre   |  %n = Tracknumber  |  %t = Title
 """
 import sys
-
-try:
-    from docopt import docopt  # Creating command-line interface
-except ImportError:
-    sys.stderr.write("""
-        %s is not installed: this program won't run correctly.
-        """ % ("docopt"))
-
 import subprocess
 import re
 import os
+import argparse
 
-__version__ = "2.1.1"
+
+__version__ = "2.2.0"
 
 TAGS = dict(a='artist', b='album', c='composer', d='date',
             g='genre', n='tracknumber', t='title')
 
 
+def parse_args(sys_args):  # pylint: disable=W0613
+    """CLI arguments comprehension"""
+    example_text = '''example:
+        $ rename-flac "%n - %t" "/media/Main/Musique/The Beatles"'''
+    parser = argparse.ArgumentParser(prog='rename-flac',
+                                 formatter_class=argparse.RawDescriptionHelpFormatter,
+                                 description=__doc__,
+                                 epilog=example_text)
+    parser.add_argument('scheme', type=str,
+                    help='filenaming scheme')
+    parser.add_argument('directory', type=str,
+                    help='path to the directory containing the album')
+    parser.add_argument('--version', action='version', version='%(prog)s ' + __version__)
+    parser.add_argument('--verbose', action='store_true',
+                    help='run the program in verbose mode')
+    return parser.parse_args()
+
+
 def scheme_processing(args):
     """Process the scheming arguments."""
-    scheme = args["<scheme>"]
-    if not re.search("%[tn]", scheme):  # To have a unique filename
+    if not re.search("%[tn]", args.scheme):  # To have a unique filename
         raise ValueError("%t or %n has to be present in <scheme>")
     scheme = re.sub('%%([%s])' % ''.join(TAGS.keys()),
                     lambda m: '%%(%s)s' % TAGS[m.group(1)],
-                    scheme)
+                    args.scheme)
     return scheme
 
 
 def fetch_metadata(filepath):
     """Fetch metadata and format it."""
-    args = ["--show-tag=%s" % tag for tag in TAGS.values()]
+    mf_args = ["--show-tag=%s" % tag for tag in TAGS.values()]
     tags = ["%s=" % tag for tag in TAGS.values()]
     # make sure the keys exist. Prevents failure in case of incomplete metadata
     metadata = dict.fromkeys(list(TAGS.values()), '')
-    pipe = subprocess.Popen(["metaflac"] + args + [filepath],
+    pipe = subprocess.Popen(["metaflac"] + mf_args + [filepath],
                             stdout=subprocess.PIPE)
     output, error = pipe.communicate()
     if pipe.returncode:
@@ -83,24 +79,24 @@ def rename(scheme, dirname, filename, args):
     filepath = os.path.join(dirname, filename)
     new_filename = scheme % fetch_metadata(filepath) + ".flac"
     if new_filename == filename:
-        if args["--verbose"]:
+        if args.verbose:
             print('"%s" is already named correctly' % filename)
     else:
         new_filepath = os.path.join(dirname, new_filename)
         os.rename(filepath, new_filepath)
-        if args["--verbose"]:
+        if args.verbose:
             print('"%s" --> "%s"' % (filename, new_filename))
 
 
 def main():
     """Main function."""
-    args = docopt(__doc__, version="rename-flac %s" % __version__)
+    args = parse_args(sys.argv[1:])
     scheme = scheme_processing(args)
-    if not os.path.isdir(args["<directory>"]):
+    if not os.path.isdir(args.directory):
         raise NotADirectoryError("%s is not a valid directory"
-                                 % args["<directory>"])
+                                 % args.directory)
     counter = 0
-    for dirname, _, filenames in os.walk(args["<directory>"], topdown=False):
+    for dirname, _, filenames in os.walk(args.directory, topdown=False):
         for filename in sorted(filenames):
             if filename.endswith('.flac'):
                 counter += 1
@@ -113,7 +109,7 @@ def main():
                              % filename)
     if counter < 1:
         raise FileNotFoundError("No FLAC files found in %s"
-                                 % args["<directory>"])
+                                 % args.directory)
 
 
 if __name__ == "__main__":
